@@ -40,6 +40,7 @@ def list_geobr():
         {"Function": "read_amazon", "Geography": "Amazon", "Years": "All", "Source": "IBGE, MMA, and others"},
         {"Function": "read_biomes", "Geography": "Biomes", "Years": "2004, 2019", "Source": "IBGE"},
         {"Function": "read_conservation_units", "Geography": "Conservation units", "Years": "All", "Source": "MMA"},
+        {"Function": "read_conservation_units_without_delimitation", "Geography": "Conservation units without delimitation", "Years": "All", "Source": "MMA"},
         {"Function": "read_disaster_risk_area", "Geography": "Disaster risk areas", "Years": "2010", "Source": "CEMADEN and IBGE"},
         {"Function": "read_indigenous_land", "Geography": "Indigenous lands", "Years": "All", "Source": "FUNAI"},
         {"Function": "read_indigenous_village", "Geography": "Indigenous villages", "Years": "All", "Source": "FUNAI"},
@@ -49,6 +50,7 @@ def list_geobr():
         {"Function": "read_neighborhoods_2022", "Geography": "Neighborhoods 2022", "Years": "2022", "Source": "IBGE"},
         {"Function": "read_schools", "Geography": "Schools", "Years": "All", "Source": "INEP"},
         {"Function": "read_ports", "Geography": "Ports", "Years": "All", "Source": "Ministério da Infraestrutura"},
+        {"Function": "read_dup", "Geography": "DUP - Declaração de Utilidade Pública", "Years": "All", "Source": "ANEEL"},
         {"Function": "read_municipal_seat", "Geography": "Municipal seats", "Years": "All", "Source": "IBGE"},
         {"Function": "read_pop_arrangements", "Geography": "Population arrangements", "Years": "2015", "Source": "IBGE"},
         {"Function": "read_rppn", "Geography": "Private Natural Heritage Reserves", "Years": "All", "Source": "ICMBio"},
@@ -145,6 +147,7 @@ def list_geobr():
         {"Function": "read_exploration_blocks", "Geography": "Oil and Gas Exploration Blocks", "Years": "All", "Source": "ANP"},
         {"Function": "read_production_fields", "Geography": "Oil and Gas Production Fields", "Years": "All", "Source": "ANP"},
         {"Function": "read_oil_wells", "Geography": "Oil and Gas Wells", "Years": "All", "Source": "ANP"},
+        {"Function": "read_2d_seismic", "Geography": "2D Seismic Surveys", "Years": "All", "Source": "ANP"},
         {"Function": "read_fuel_bases", "Geography": "Fuel Bases", "Years": "All", "Source": "EPE"},
         {"Function": "read_glp_bases", "Geography": "GLP (LPG) Bases", "Years": "All", "Source": "EPE"},
         {"Function": "read_processing_facilities", "Geography": "Oil and Gas Processing Facilities", "Years": "All", "Source": "EPE"},
